@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use experimental 'signatures', 'declared_refs';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Iterator::Flex::Factory;
 use Iterator::Flex::Utils qw[ THROW STATE EXHAUSTION :IterAttrs :IterStates ];
@@ -208,7 +208,7 @@ sub construct ( $class, $state ) {
         },
 
         ( +RESET )    => sub { @value = () },
-        ( +REWIND )   => sub { @value = () },
+        ( +REWIND )   => sub { },
         ( +_DEPENDS ) => \@iterators,
     );
 
@@ -381,7 +381,7 @@ Iterator::Flex::Zip - Zip Iterator Class
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 METHODS
 
